@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.360';
+$Config::Model::TkUI::VERSION = '1.361';
 use 5.10.1;
 use strict;
 use warnings;
@@ -301,7 +301,7 @@ sub Populate {
     $cw->Advertise( find_frame  => $find_frame );
     $cw->Advertise( msg_label   => $msg_label );
 
-    $cw->OnDestroy(sub { $cw->Parent->destroy } );
+    $cw->OnDestroy(sub {$cw->Parent->destroy if ref($cw->Parent) eq 'MainWindow'} );
 
     $cw->Delegates;
 }
